%define major     3
%define libname   %mklibname %{name} %{major}
%define develname %mklibname %{name} -d

%bcond_without jpegxl

Name:       aom
Version:    3.8.2
Release:    %mkrel 2
Summary:    Royalty-free next-generation video format
Group:      System/Libraries
License:    BSD
URL:        https://aomedia.org/
Source0:    https://aomedia.googlesource.com/%{name}/+archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz

BuildRequires:  gcc-c++
BuildRequires:  gcc
BuildRequires:  cmake
BuildRequires:  doxygen
BuildRequires:  git-core
BuildRequires:  graphviz
BuildRequires:  perl(Getopt::Long)
BuildRequires:  wxgtk-devel
BuildRequires:  yasm
BuildRequires:  ccache
%if %{with jpegxl}
BuildRequires:  pkgconfig(libjxl)
BuildRequires:  pkgconfig(libhwy)
%endif
Provides:       av1 = %{version}-%{release}

%description
The Alliance for Open Media’s focus is to deliver a next-generation
video format that is:

 - Interoperable and open;
 - Optimized for the Internet;
 - Scalable to any modern device at any bandwidth;
 - Designed with a low computational footprint and optimized for hardware;
 - Capable of consistent, highest-quality, real-time video delivery; and
 - Flexible for both commercial and non-commercial content, including
   user-generated content.

This package contains the reference encoder and decoder.


%package -n %{libname}
Summary:        Library files for aom
Group:          System/Libraries

%description -n %{libname}
Library files for aom, the royalty-free next-generation 
video format.


%package -n %{develname}
Summary:        Development files for aom
Group:          Development/C
Requires:       %{name} = %{version}-%{release}
Requires:       %{libname} = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}

%description -n %{develname}
Development files for aom, the royalty-free next-generation 
video format.


%prep
%autosetup -p1 -c %{name}-%{version}


%build
%cmake      -DENABLE_CCACHE=1 \
            -DCMAKE_SKIP_RPATH=1 \
%ifnarch aarch64 %{arm} %{ix86} x86_64
            -DAOM_TARGET_CPU=generic \
%endif
%ifarch %{arm}
            -DAOM_TARGET_CPU=arm \
%endif
%ifarch aarch64
            -DAOM_TARGET_CPU=arm64 \
%endif
%ifarch %{ix86}
            -DAOM_TARGET_CPU=x86 \
%endif
%ifarch x86_64
            -DAOM_TARGET_CPU=x86_64 \
%endif
            -DCONFIG_WEBM_IO=1 \
            -DENABLE_DOCS=1 \
	    -DENABLE_TESTS=0 \
	    -DCONFIG_INSPECTION=1 \
            -DCONFIG_ANALYZER=0 \
            -DFORCE_HIGHBITDEPTH_DECODING=0 \
	    -DBUILD_SHARED_LIBS=1 \
%if %{with jpegxl}
	    -DCONFIG_TUNE_BUTTERAUGLI=1 \
%endif
	    -DLIB_INSTALL_DIR=%{_lib} \
	    -DCMAKE_INSTALL_LIBDIR=%{_lib}
%cmake_build

%install
%cmake_install

# Delete static library
find %{buildroot} -name libaom.a -delete

%files
%doc AUTHORS CHANGELOG README.md
%license LICENSE PATENTS
%{_bindir}/aomdec
%{_bindir}/aomenc


%files -n %{libname}
%license LICENSE PATENTS
%{_libdir}/libaom.so.%{major}{,.*}


%files -n %{develname}
%doc build/docs/html/
%{_includedir}/%{name}/
%{_libdir}/libaom.so
%{_libdir}/pkgconfig/%{name}.pc


%changelog
* Mon May 06 2024 daviddavid <daviddavid> 3.8.2-2.mga10
+ Revision: 2062551
- fix arm build
- new version: 3.8.2

* Sun Mar 10 2024 daviddavid <daviddavid> 3.8.1-1.mga10
+ Revision: 2048955
- new version: 3.8.1

* Tue Nov 07 2023 daviddavid <daviddavid> 3.7.0-2.mga10
+ Revision: 2005048
- rebuild for new libjxl 0.8.2

* Sat Sep 16 2023 daviddavid <daviddavid> 3.7.0-1.mga10
+ Revision: 1987062
- new version: 3.7.0

* Mon Mar 20 2023 luigiwalser <luigiwalser> 3.6.0-1.mga9
+ Revision: 1949873
- 3.6.0

* Mon Jan 16 2023 daviddavid <daviddavid> 3.5.0-3.mga9
+ Revision: 1933672
- really enable jpeg-xl support

* Mon Jan 16 2023 daviddavid <daviddavid> 3.5.0-2.mga9
+ Revision: 1933668
- enable jpeg-xl support

* Fri Nov 11 2022 luigiwalser <luigiwalser> 3.5.0-1.mga9
+ Revision: 1905604
- 3.5.0
- update source URL

* Sun Aug 14 2022 neoclust <neoclust> 3.4.0-1.mga9
+ Revision: 1877617
- New version 3.4.0

* Sun Apr 03 2022 umeabot <umeabot> 3.2.0-2.mga9
+ Revision: 1842677
- Mageia 9 Mass Rebuild

* Sat Oct 16 2021 luigiwalser <luigiwalser> 3.2.0-1.mga9
+ Revision: 1751882
- 3.2.0

* Wed Aug 04 2021 luigiwalser <luigiwalser> 3.1.2-1.mga9
+ Revision: 1739347
- 3.1.2

* Fri Jul 16 2021 luigiwalser <luigiwalser> 3.1.1-1.mga9
+ Revision: 1736226
- 3.1.1
- library major is now 3
- remove upstream CVE patches
- disable analyzer (no longer builds)

* Tue Jul 06 2021 ns80 <ns80> 2.0.1-4.mga9
+ Revision: 1734968
- backport upstream patches for CVE-2021-3047[35] (mga#29144)

* Fri Jan 01 2021 wally <wally> 2.0.1-3.mga8
+ Revision: 1667828
- rebuild for wxgtk pre 3.1.5 snapshot

* Wed Dec 30 2020 luigiwalser <luigiwalser> 2.0.1-1.mga8
+ Revision: 1665530
- 2.0.1

* Sun Aug 16 2020 wally <wally> 2.0.0-2.mga8
+ Revision: 1614324
- rebuild for new wxgtk 3.1.4

* Mon Jun 15 2020 kekepower <kekepower> 2.0.0-1.mga8
+ Revision: 1593409
- Add extra flag for arm

* Thu Jun 04 2020 kekepower <kekepower> 2.0.0-0.20200518gitbb35ba9.1.mga8
+ Revision: 1590338
- Fix cmake options
- Delete static library
- Lib major is now 2
+ zezinho <zezinho>
- new version 2.0.0

* Tue Feb 18 2020 umeabot <umeabot> 1.0.0-0.20180925gitd0076f5.4.mga8
+ Revision: 1537905
- Mageia 8 Mass Rebuild
+ wally <wally>
- build with new cmake macros

* Tue Nov 12 2019 wally <wally> 1.0.0-0.20180925gitd0076f5.3.mga8
+ Revision: 1459450
- rebuild for wxgtk 3.1.3

* Mon Jul 08 2019 wally <wally> 1.0.0-0.20180925gitd0076f5.2.mga8
+ Revision: 1419519
- rebuild for wxgtk 3.1.2 with 2.8 compatibility

* Sun Jul 07 2019 wally <wally> 1.0.0-0.20180925gitd0076f5.1.mga8
+ Revision: 1419295
- build with gtk3 enabled wxgtk 3.1.2

* Mon Feb 04 2019 zezinho <zezinho> 1.0.0-0.20180925gitd0076f5.mga7
+ Revision: 1363182
- start from fedora spec
- imported package aom


* Thu Jan 31 2019 Fedora Release Engineering <releng@fedoraproject.org> - 1.0.0-6.20180925gitd0076f5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Tue Sep 25 2018 Robert-André Mauchin <zebob.m@gmail.com> - 1.0.0-5.20180925gitd0076f5
- Update to commit d0076f507a6027455540e2e4f25f84ca38803e07
- Set CONFIG_LOWBITDEPTH to 1
- Fix #1632658

* Thu Sep 13 2018 Robert-André Mauchin <zebob.m@gmail.com> - 1.0.0-4
- Split the package into libs/tools

* Tue Sep 11 2018 Robert-André Mauchin <zebob.m@gmail.com> - 1.0.0-3
- Update the archive in order to detect the correct version from the changelog

* Thu Jul 12 2018 Fedora Release Engineering <releng@fedoraproject.org> - 1.0.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Wed Mar 07 2018 Robert-André Mauchin <zebob.m@gmail.com> - 1.0.0-1
- First RPM release

